macro_rules! register_blocks {
( $( $block_name:ty ),* ) => { ... };
}Expand description
Macro for statically registering all the blocks that are available in the system.
macro_rules! register_blocks {
( $( $block_name:ty ),* ) => { ... };
}Macro for statically registering all the blocks that are available in the system.